@@ -6,20 +6,19 @@ NUM_CENARIOS = 2000
 MAX_ANOS_ESTUDO = 30
 MAX_ANOS_HISTORICO = 120
 MAX_CONFIGURACOES = 360
-MAX_SUBMERCADOS = 10
+MAX_SUBMERCADOS = 15
 MAX_ITERS = 100
 MAX_FORWARDS = 300
 MAX_CORTES = MAX_ITERS * MAX_FORWARDS
-MAX_UHES = 300
+MAX_UHES = 330
+MAX_CONJUNTOS_MAQUINAS = 5
 MAX_UTES = 300
 MAX_RES = 100
 MAX_REES = 30
-NUM_PATAMARES = 3
 MAX_LAG_ADTERM = 2
 NUM_CONFIGS_DGER = 100
 NUM_VARIAVEIS_MEDIAS = 52
-NUM_VARIAVEIS_CUSTO_PMO = 16
-ORDEM_MAX_PARP = 6
+ORDEM_MAX_PARP = 11
 MESES = [
     "JANEIRO",
     "FEVEREIRO",
